RegularFile

Enum RegularFile 

pub enum RegularFile<ObjectID: FsVerityHashValue> {
    Inline(Box<[u8]>),
    External(ObjectID, u64),
    ExternalNoVerity(ObjectID, u64),
    Sparse(u64),
}
Represents a regular file’s content storage strategy in composefs.

Files can be stored inline for small content or externally referenced for larger files using fsverity hashing.

Variants



Inline(Box<[u8]>)

File content stored inline as raw bytes.



External(ObjectID, u64)

File stored externally, referenced by fsverity hash and size.

The tuple contains (fsverity hash, file size in bytes). The fsverity digest is embedded in the overlay metacopy xattr.



ExternalNoVerity(ObjectID, u64)

Like External, but without embedding the fsverity digest in the overlay metacopy xattr. Used by the C API when the caller set a content-address payload but did not explicitly set a verified digest.



Sparse(u64)

File with declared size but no content or external reference. Produces ChunkBased layout with null chunk indices.

Implementations

Source

impl<ObjectID: FsVerityHashValue> RegularFile<ObjectID>

pub fn file_size(&self) -> u64

Returns the file size in bytes.