Rust bindings and utilities for working with composefs images and repositories.
Composefs is a read-only FUSE filesystem that enables efficient sharing of container filesystem layers by using content-addressable storage and fs-verity for integrity verification.
Re-exports
pub use repository::ImageNotFound;
Modules
- dumpfile
- Reading and writing composefs dumpfile format.
- dumpfile_
parse - Parsing and generating composefs dump file entry
- erofs
- EROFS (Enhanced Read-Only File System) format support for composefs.
- filesystem_
ops - High-level filesystem operations for composefs trees.
- fs
- Reading and writing filesystem trees to/from disk.
- fsverity
- Linux fs-verity support for integrity verification.
- generic_
tree - A generic metadata-only filesystem tree where regular files can be stored however the caller wants.
- mount
- Modern Linux mount API support for composefs.
- mountcompat
- Compatibility helpers for older Linux kernel mount APIs.
- progress
- Progress reporting API for pull and download operations.
- repository
- Content-addressable repository for composefs objects.
- splitstream
- Split Stream file format implementation.
- tree
- A filesystem tree which stores regular files using the composefs strategy of inlining small files, and having an external fsverity reference for larger ones.
- util
- Utility functions and types used throughout the composefs crate.
Constants
- INLINE_
CONTENT_ MAX_ V0 - Files with this many bytes or fewer are stored inline in the erofs image (and in splitstreams). Files above this threshold are written to object storage and referenced via overlay metacopy xattrs.
- MAX_
INLINE_ CONTENT - Maximum inline content size accepted when parsing untrusted input (dumpfiles, EROFS images in composefs-restricted mode).
- SYMLINK_
MAX - Maximum symlink target length in bytes.